==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QEvent_shell.cpp <==
#include "QEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QEvent")
    QEvent *_ptr = reinterpret_cast<QEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QEvent_shell) ); }

jmethodID QEvent_shell::__shell_javaMethod(int pos) const { return QEvent_shell::__shell()->javaMethod(typeid(QEvent), pos); }

// emitting (writeShellConstructor)
QEvent_shell::QEvent_shell(const QEvent& other0)
    : QEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QEvent::QEvent_shell(const QEvent& other0)", QEvent_shell::__shell())
    QEvent_shell::__shell()->constructed(typeid(QEvent));
}

QEvent_shell::QEvent_shell(QEvent::Type type0)
    : QEvent(type0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QEvent::QEvent_shell(QEvent::Type type0)", QEvent_shell::__shell())
    QEvent_shell::__shell()->constructed(typeid(QEvent));
}

// emitting (writeShellDestructor)
QEvent_shell::~QEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QEvent::~QEvent()", QEvent_shell::__shell())
    QEvent_shell::__shell()->destructed(typeid(QEvent));
}

void QEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QEvent_shell*>(ptr)->QEvent_shell::__shell()->tryDeleteShell(typeid(QEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QEvent(QEvent)
void __qt_construct_QEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEvent(QEvent)")
    jobject other0 = __java_arguments[0].l;
    const QEvent& __qt_other0 = qtjambi_cast<const QEvent& >(__jni_env, other0);
    QEvent *__qt_this = new(__qtjambi_ptr) QEvent_shell(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QEvent(QEvent::Type)
void __qt_construct_QEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEvent(QEvent::Type)")
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    QEvent *__qt_this = new(__qtjambi_ptr) QEvent_shell(QEvent::Type(__qt_type0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QEvent_shell
void __qt_destruct_QEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QEvent")
    reinterpret_cast<QEvent_shell*>(ptr)->~QEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QEvent::QEvent(QEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_initialize_1native__Lio_qt_core_QEvent_2Lio_qt_core_QEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEvent::QEvent(QEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEvent_0, sizeof(QEvent_shell), typeid(QEvent), true, &deleter_QEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::QEvent(QEvent::Type)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_initialize_1native__Lio_qt_core_QEvent_2Lio_qt_core_QEvent_00024Type_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEvent::QEvent(QEvent::Type)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = type0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEvent_1, sizeof(QEvent_shell), typeid(QEvent), true, &deleter_QEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::ignore()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_ignore_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::ignore()", __qt_this)
        __qt_this->ignore();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::isAccepted()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_isAccepted_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::isAccepted()const", __qt_this)
        __java_return_value = __qt_this->isAccepted();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QEvent::operator=(QEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_assign_1native_1cref_1QEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::operator=(QEvent)", __qt_this)
        const QEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QEvent>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::setAccepted(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_setAccepted_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean accepted0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::setAccepted(bool)", __qt_this)
        __qt_this->setAccepted(static_cast<bool>(accepted0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::spontaneous()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_spontaneous_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::spontaneous()const", __qt_this)
        __java_return_value = __qt_this->spontaneous();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QEvent::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::type()const", __qt_this)
        QEvent::Type __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QEvent::registerEventType(int)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_registerEventType__I)
(JNIEnv *__jni_env,
 jclass,
 jint hint0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEvent::registerEventType(int)")
    jint __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QEvent::registerEventType(static_cast<int>(hint0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QEvent>("QEvent", "io/qt/core/QEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QEvent, {
        ConstructorInfo(&__qt_construct_QEvent_0, "Lio/qt/core/QEvent;")
       ,ConstructorInfo(&__qt_construct_QEvent_1, "Lio/qt/core/QEvent$Type;")
    });
// END: function table

    registerMetaObject(typeId, QEvent::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QEvent);
    registerSizeOfShell(typeId, sizeof(QEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QEvent::Type>("QEvent::Type", "io/qt/core/QEvent$Type");
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QEvent_shell.cpp <==
#include "QEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QEvent")
    QEvent *_ptr = reinterpret_cast<QEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QEvent_shell) ); }

jmethodID QEvent_shell::__shell_javaMethod(int pos) const { return QEvent_shell::__shell()->javaMethod(typeid(QEvent), pos); }

// emitting (writeShellConstructor)
QEvent_shell::QEvent_shell(const QEvent& other0)
    : QEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QEvent::QEvent_shell(const QEvent& other0)", QEvent_shell::__shell())
    QEvent_shell::__shell()->constructed(typeid(QEvent));
}

QEvent_shell::QEvent_shell(QEvent::Type type0)
    : QEvent(type0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QEvent::QEvent_shell(QEvent::Type type0)", QEvent_shell::__shell())
    QEvent_shell::__shell()->constructed(typeid(QEvent));
}

// emitting (writeShellDestructor)
QEvent_shell::~QEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QEvent::~QEvent()", QEvent_shell::__shell())
    QEvent_shell::__shell()->destructed(typeid(QEvent));
}

void QEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QEvent_shell*>(ptr)->QEvent_shell::__shell()->tryDeleteShell(typeid(QEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QEvent(QEvent)
void __qt_construct_QEvent_cref_QEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEvent(QEvent)")
    jobject other0 = __java_arguments[0].l;
    const QEvent& __qt_other0 = qtjambi_cast<const QEvent& >(__jni_env, other0);
    QEvent *__qt_this = new(__qtjambi_ptr) QEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QEvent::QEvent(QEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_initialize_1native__Lio_qt_core_QEvent_2Lio_qt_core_QEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEvent::QEvent(QEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEvent_cref_QEvent, sizeof(QEvent_shell), typeid(QEvent), true, &deleter_QEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QEvent(QEvent::Type)
void __qt_construct_QEvent_QEvent_Type(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QEvent(QEvent::Type)")
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    QEvent *__qt_this = new(__qtjambi_ptr) QEvent_shell(QEvent::Type(__qt_type0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QEvent::QEvent(QEvent::Type)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_initialize_1native__Lio_qt_core_QEvent_2Lio_qt_core_QEvent_00024Type_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEvent::QEvent(QEvent::Type)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = type0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QEvent_QEvent_Type, sizeof(QEvent_shell), typeid(QEvent), true, &deleter_QEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QEvent_shell
void __qt_destruct_QEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QEvent")
    reinterpret_cast<QEvent_shell*>(ptr)->~QEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QEvent::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::ignore()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_ignore_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::ignore()", __qt_this)
        __qt_this->ignore();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::isAccepted()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_isAccepted_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::isAccepted()const", __qt_this)
        __java_return_value = __qt_this->isAccepted();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QEvent::operator=(QEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_assign_1native_1cref_1QEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::operator=(QEvent)", __qt_this)
        const QEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QEvent>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::setAccepted(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_setAccepted_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean accepted0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::setAccepted(bool)", __qt_this)
        __qt_this->setAccepted(static_cast<bool>(accepted0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QEvent::spontaneous()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_spontaneous_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::spontaneous()const", __qt_this)
        __java_return_value = __qt_this->spontaneous();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QEvent::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QEvent::type()const", __qt_this)
        QEvent::Type __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QEvent::registerEventType(int)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_registerEventType__I)
(JNIEnv *__jni_env,
 jclass,
 jint hint0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QEvent::registerEventType(int)")
    jint __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QEvent::registerEventType(static_cast<int>(hint0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QEvent *__qt_this = QtJambiAPI::objectFromNativeId<QEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QEvent>("QEvent", "io/qt/core/QEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QEvent, {
        ConstructorInfo(&__qt_construct_QEvent_cref_QEvent, "Lio/qt/core/QEvent;")
       ,ConstructorInfo(&__qt_construct_QEvent_QEvent_Type, "Lio/qt/core/QEvent$Type;")
    });
// END: function table

    registerMetaObject(typeId, QEvent::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QEvent);
    registerSizeOfShell(typeId, sizeof(QEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QEvent::Type>("QEvent::Type", "io/qt/core/QEvent$Type");
// END: enums and flags
}
